@@ -15,11 +15,12 @@ import math
 
 
 class PDFAQuantizationNAryTreeLearner:
-    def __init__(self, probabilityPartitioner: ProbabilityPartitioner, pre_cache_queries_for_building_hipothesis = False):
+    def __init__(self, probabilityPartitioner: ProbabilityPartitioner, pre_cache_queries_for_building_hipothesis = False, check_probabilistic_hipothesis = True):
         self.probability_partitioner = probabilityPartitioner
         self._pre_cache_queries_for_building_hipothesis = pre_cache_queries_for_building_hipothesis
         self._verbose = False
         self._tree = None
+        self._check_probabilistic_hipothesis = check_probabilistic_hipothesis
         pass
 
     @property
@@ -137,7 +138,7 @@ class PDFAQuantizationNAryTreeLearner:
 
         comparator = WFAToleranceComparator()
         states = set(states.values())
-        return PDFA(self._alphabet, states, self.terminal_symbol, comparator=comparator)
+        return PDFA(self._alphabet, states, self.terminal_symbol, comparator=comparator, check_is_probabilistic=self._check_probabilistic_hipothesis)
 
     def get_accessing_string(self, model: PDFA, sequence: Sequence):
         state = model.get_first_state()
